@@ -5,35 +5,35 @@ import re
 import sys
 from itertools import chain
 from pathlib import Path
+from typing import Dict, Pattern, Set
 
-import toml
+import tomli
+from robot.utils import FileReader
 
 from robocop.exceptions import (
     ArgumentFileNotFoundError,
-    NestedArgumentFileError,
-    InvalidArgumentError,
+    CircularArgumentFileError,
     ConfigGeneralError,
+    InvalidArgumentError,
 )
+from robocop.files import DEFAULT_EXCLUDES, find_file_in_project_root, find_project_root
 from robocop.rules import RuleSeverity
 from robocop.utils import RecommendationFinder
 from robocop.version import __version__
 
 
-def translate_pattern(pattern):
+def translate_pattern(pattern: str) -> Pattern:
     return re.compile(fnmatch.translate(pattern))
 
 
-def find_severity_value(severity):
-    for sev in RuleSeverity:
-        if sev.value == severity.upper():
-            return sev
-    return RuleSeverity.INFO
-
-
 class ParseDelimitedArgAction(argparse.Action):  # pylint: disable=too-few-public-methods
     def __call__(self, parser, namespace, values, option_string=None):
         container = getattr(namespace, self.dest)
-        container.update(values.split(","))
+        config_values = values.split(",")
+        if isinstance(container, list):
+            container.extend(config_values)
+        else:
+            container.update(values.split(","))
 
 
 class ParseCheckerConfig(argparse.Action):  # pylint: disable=too-few-public-methods
@@ -52,7 +52,7 @@ class ParseFileTypes(argparse.Action):  # pylint: disable=too-few-public-methods
 
 class SetRuleThreshold(argparse.Action):
     def __call__(self, parser, namespace, values, option_string=None):
-        setattr(namespace, self.dest, find_severity_value(values))
+        setattr(namespace, self.dest, RuleSeverity.parser(values, rule_severity=False))
 
 
 class SetListOption(argparse.Action):
@@ -75,16 +75,107 @@ class CustomArgParser(argparse.ArgumentParser):
             raise InvalidArgumentError(message)
 
 
+def validate_regex(pattern: str) -> Pattern:
+    try:
+        return re.compile(pattern) if pattern is not None else None
+    except re.error:
+        raise ConfigGeneralError(f"Provided regex pattern {pattern} failed to be compiled")
+
+
+def resolve_relative_path(orig_path, config_dir: Path, ensure_exists: bool):
+    path = Path(orig_path)
+    if path.is_absolute():
+        return orig_path
+    resolved_path = config_dir / path
+    if not ensure_exists or resolved_path.exists():
+        return str(resolved_path)
+    return orig_path
+
+
+class ArgumentFileParser:
+    ARGUMENT_FILE_OPTIONS = {"-A", "--argumentfile"}
+    RESOLVE_PATHS_OPTIONS = {"-o", "--output", "-rules", "--ext-rules"}
+    ENSURE_EXIST_PATHS_OPTIONS = {"-rules", "--ext-rules"}
+
+    def __init__(self):
+        self.loaded_argument_files = set()
+        self.config_from = ""
+
+    def expand_argument_files(self, args, config_dir=None):
+        """
+        Find argument files in the argument list and expand argument list with their content.
+        """
+        if not any(arg in self.ARGUMENT_FILE_OPTIONS for arg in args):
+            return list(args)
+        parsed_args = []
+        while args:
+            arg = args.pop(0)
+            if arg not in self.ARGUMENT_FILE_OPTIONS:
+                parsed_args.append(arg)
+                continue
+            if not args:  # argumentfile option declared but filename was not provided
+                raise ArgumentFileNotFoundError("") from None
+            argfile = args.pop(0)
+            argfile_path = Path(argfile)
+            if argfile_path.is_file():
+                loaded_config_dir = argfile_path.parent
+            else:
+                loaded_config_dir = None
+            file_args = self.load_argument_file(argfile, config_dir)
+            file_args = self.resolve_arguments_paths(file_args, config_dir)
+            parsed_args += self.expand_argument_files(file_args, loaded_config_dir)
+        return parsed_args
+
+    def resolve_arguments_paths(self, args, root_dir):
+        if root_dir is None:
+            return args
+        prev_option_like = False
+        prev_arg = "option"
+        resolved = []
+        for arg in args:
+            if (prev_option_like and prev_arg in self.RESOLVE_PATHS_OPTIONS) or prev_option_like:
+                ensure_exists = prev_arg in self.ENSURE_EXIST_PATHS_OPTIONS
+                # TODO: If the --rules is provided as comma separated list, it will not resolve paths
+                arg = resolve_relative_path(arg, root_dir, ensure_exists)
+            resolved.append(arg)
+            prev_option_like = arg.startswith("-")
+            prev_arg = arg
+        return resolved
+
+    def load_argument_file(self, argfile, config_dir):
+        if config_dir is not None:
+            argfile = resolve_relative_path(argfile, config_dir, True)
+        if argfile in self.loaded_argument_files:
+            raise CircularArgumentFileError(argfile) from None
+        else:
+            self.loaded_argument_files.add(argfile)
+        try:
+            with FileReader(argfile) as arg_f:
+                args = []
+                for line in arg_f.readlines():
+                    if line.strip().startswith("#"):
+                        continue
+                    for arg in line.split(" ", 1):
+                        arg = arg.strip()
+                        if arg:
+                            args.append(arg)
+                if args and not self.config_from:
+                    self.config_from = argfile
+                return args
+        except FileNotFoundError:
+            raise ArgumentFileNotFoundError(argfile) from None
+
+
 class Config:
-    def __init__(self, root=None, from_cli=False):
+    def __init__(self, root=None, from_cli: bool = False):
         self.from_cli = from_cli
         self.exec_dir = os.path.abspath(".")
-        self.root = Path(root) if root is not None else root
         self.include = set()
         self.exclude = set()
         self.ignore = set()
-        self.reports = {"return_status"}
-        self.threshold = RuleSeverity.INFO
+        self.ignore_default = re.compile(DEFAULT_EXCLUDES)
+        self.reports = ["return_status"]
+        self.threshold = RuleSeverity("I")
         self.configure = []
         self.format = "{source}:{line}:{col} [{severity}] {rule_id} {desc} ({name})"
         self.paths = ["."]
@@ -92,6 +183,7 @@ class Config:
         self.include_patterns = []
         self.exclude_patterns = []
         self.filetypes = {".robot", ".resource", ".tsv"}
+        self.language = []
         self.list = ""
         self.list_configurables = ""
         self.list_reports = False
@@ -99,44 +191,8 @@ class Config:
         self.recursive = True
         self.verbose = False
         self.config_from = ""
-        self.parser = self._create_parser()
-
-    HELP_MSGS = {
-        "help_paths": "List of paths (files or directories) to be parsed by Robocop.",
-        "help_include": "Run Robocop only with specified rules. You can define rule by its name or id.\n"
-        "Glob patterns are supported.",
-        "help_exclude": "Ignore specified rules. You can define rule by its name or id.\n"
-        "Glob patterns are supported.",
-        "help_ext_rules": "List of paths with custom rules.",
-        "help_reports": "Generate reports after scan. You can enable reports by listing them in comma\n"
-        "separated list:\n"
-        "--reports rules_by_id,rules_by_error_type,scan_timer\n"
-        "To enable all reports use all:\n"
-        "--report all",
-        "help_format": "Format of output message. "
-        "You can use placeholders to change the way an issue is reported.\n"
-        "Default: {source}:{line}:{col} [{severity}] {rule_id} {desc} ({name})",
-        "help_configure": "Configure checker or report with parameter value. Usage:\n"
-        "-c message_name_or_id:param_name:param_value\nExample:\n"
-        "-c line-too-long:line_length:150\n"
-        "--configure 0101:severity:E",
-        "help_list": "List all available rules. You can use optional pattern argument.",
-        "help_list_confs": "List all available rules with configurable parameters. "
-        "You can use optional pattern argument.",
-        "help_list_reports": "List all available reports.",
-        "help_output": "Path to output file.",
-        "help_filetypes": "Comma separated list of file extensions to be scanned by Robocop",
-        "help_threshold": f"Disable rules below given threshold. Available message levels: "
-        f'{" < ".join(sev.value for sev in RuleSeverity)}',
-        "help_recursive": "Use this flag to stop scanning directories recursively.",
-        "help_argfile": "Path to file with arguments.",
-        "help_ignore": "Ignore file(s) and path(s) provided. Glob patterns are supported.",
-        "help_info": "Print this help message and exit.",
-        "help_version": "Display Robocop version.",
-        "help_verbose": "Display extra information.",
-        "directives": "1. Serve the public trust\n2. Protect the innocent\n3. Uphold the law\n4. [ACCESS " "DENIED]",
-        "epilog": "For full documentation visit: https://github.com/MarketSquare/robotframework-robocop",
-    }
+        self.root = find_project_root(root, ["."])
+        self.parse()
 
     def remove_severity(self):
         self.include = {self.replace_severity_values(rule) for rule in self.include}
@@ -162,47 +218,12 @@ class Config:
         self.include = self.filter_patterns_from_names(self.include, self.include_patterns)
         self.exclude = self.filter_patterns_from_names(self.exclude, self.exclude_patterns)
 
-    def preparse(self, args):
-        args = sys.argv[1:] if args is None else args
-        parsed_args = []
-        args = (arg for arg in args)
-        for arg in args:
-            if arg in ("-A", "--argumentfile"):
-                try:
-                    argfile = next(args)
-                except StopIteration:
-                    raise ArgumentFileNotFoundError("") from None
-                parsed_args += self.load_args_from_file(argfile)
-            else:
-                parsed_args.append(arg)
-        return parsed_args
-
-    def load_args_from_file(self, argfile):
-        try:
-            with open(argfile) as arg_f:
-                args = []
-                for line in arg_f:
-                    if line.strip().startswith("#"):
-                        continue
-                    for arg in line.split(" ", 1):
-                        arg = arg.strip()
-                        if not arg:
-                            continue
-                        args.append(arg)
-                if "-A" in args or "--argumentfile" in args:
-                    raise NestedArgumentFileError(argfile)
-                if args:
-                    self.config_from = argfile
-                return args
-        except FileNotFoundError:
-            raise ArgumentFileNotFoundError(argfile) from None
-
     def _create_parser(self):
         parser = CustomArgParser(
             prog="robocop",
             formatter_class=argparse.RawTextHelpFormatter,
             description="Static code analysis tool for Robot Framework",
-            epilog=self.HELP_MSGS["epilog"],
+            epilog="For full documentation visit: https://robocop.readthedocs.io/en/latest/",
             add_help=False,
             from_cli=self.from_cli,
         )
@@ -215,7 +236,7 @@ class Config:
             type=str,
             nargs="*",
             default=self.paths,
-            help=self.HELP_MSGS["help_paths"],
+            help="List of paths (files or directories) to be parsed by Robocop.",
         )
         optional.add_argument(
             "-i",
@@ -223,7 +244,8 @@ class Config:
             action=ParseDelimitedArgAction,
             default=self.include,
             metavar="RULES",
-            help=self.HELP_MSGS["help_include"],
+            help="Run Robocop only with specified rules. You can define rule by its name or id.\n"
+            "Glob patterns are supported.",
         )
         optional.add_argument(
             "-e",
@@ -231,35 +253,42 @@ class Config:
             action=ParseDelimitedArgAction,
             default=self.exclude,
             metavar="RULES",
-            help=self.HELP_MSGS["help_exclude"],
+            help="Ignore specified rules. You can define rule by its name or id.\nGlob patterns are supported.",
         )
         optional.add_argument(
             "-rules",
             "--ext-rules",
             action=ParseDelimitedArgAction,
             default=self.ext_rules,
-            help=self.HELP_MSGS["help_ext_rules"],
+            help="List of paths with custom rules.",
         )
         optional.add_argument(
             "-nr",
             "--no-recursive",
             dest="recursive",
             action="store_false",
-            help=self.HELP_MSGS["help_recursive"],
+            default=self.recursive,
+            help="Use this flag to stop scanning directories recursively.",
         )
         optional.add_argument(
             "-r",
             "--reports",
             action=ParseDelimitedArgAction,
             default=self.reports,
-            help=self.HELP_MSGS["help_reports"],
+            help="Generate reports after scan.\n"
+            "You can enable reports by listing them in comma-separated list:\n"
+            "--reports rules_by_id,rules_by_error_type,scan_timer\n"
+            "To enable all reports use all:\n"
+            "--reports all",
         )
         optional.add_argument(
             "-f",
             "--format",
             type=str,
             default=self.format,
-            help=self.HELP_MSGS["help_format"],
+            help="Format of output message. "
+            "You can use placeholders to change the way an issue is reported.\n"
+            "Default: {source}:{line}:{col} [{severity}] {rule_id} {desc} ({name})",
         )
         optional.add_argument(
             "-c",
@@ -267,7 +296,11 @@ class Config:
             action=ParseCheckerConfig,
             default=self.configure,
             metavar="CONFIGURABLE",
-            help=self.HELP_MSGS["help_configure"],
+            help="Configure checker or report with parameter value. Usage:\n"
+            "-c message_name_or_id:param_name:param_value\n"
+            "Examples:\n"
+            "-c line-too-long:line_length:150\n"
+            "--configure 0101:severity:E",
         )
         optional.add_argument(
             "-l",
@@ -277,7 +310,9 @@ class Config:
             const="",
             default=self.list,
             metavar="PATTERN",
-            help=self.HELP_MSGS["help_list"],
+            help="List all available rules. You can use optional PATTERN argument to match rule names "
+            "(for example --list *doc*). "
+            "PATTERN can be also ENABLED/DISABLED keyword to list only enabled/disabled rules.",
         )
         optional.add_argument(
             "-lc",
@@ -287,14 +322,16 @@ class Config:
             const="",
             default=self.list_configurables,
             metavar="PATTERN",
-            help=self.HELP_MSGS["help_list_confs"],
+            help="List all available rules with configurable parameters. You can use optional PATTERN argument "
+            "to match rule names (for example --list *doc*). "
+            "PATTERN can be also ENABLED/DISABLED keyword to list only enabled/disabled rules.",
         )
         optional.add_argument(
             "-lr",
             "--list-reports",
             action="store_true",
             default=self.list_reports,
-            help=self.HELP_MSGS["help_list_reports"],
+            help="List all available reports.",
         )
         optional.add_argument(
             "-o",
@@ -302,100 +339,149 @@ class Config:
             type=argparse.FileType("w"),
             default=self.output,
             metavar="PATH",
-            help=self.HELP_MSGS["help_output"],
+            help="Path to output file.",
         )
         optional.add_argument(
             "-ft",
             "--filetypes",
             action=ParseFileTypes,
             default=self.filetypes,
-            help=self.HELP_MSGS["help_filetypes"],
+            help="Comma-separated list of file extensions to be scanned by Robocop",
         )
         optional.add_argument(
             "-t",
             "--threshold",
             action=SetRuleThreshold,
             default=self.threshold,
-            help=self.HELP_MSGS["help_threshold"],
+            help=f"Disable rules below given threshold. Available message levels: "
+            f'{" < ".join(sev.value for sev in RuleSeverity)}',
         )
-        optional.add_argument("-A", "--argumentfile", metavar="PATH", help=self.HELP_MSGS["help_argfile"])
+        optional.add_argument("-A", "--argumentfile", metavar="PATH", help="Path to file with arguments.")
         optional.add_argument(
             "-g",
             "--ignore",
             action=ParseDelimitedArgAction,
             default=self.ignore,
             metavar="PATH",
-            help=self.HELP_MSGS["help_ignore"],
+            help="Ignore file(s) and path(s) provided. Glob patterns are supported.",
         )
-        optional.add_argument("-h", "--help", action="help", help=self.HELP_MSGS["help_info"])
+        optional.add_argument(
+            "-gd",
+            "--ignore-default",
+            type=validate_regex,
+            default=self.ignore_default,
+            metavar="PATTERN",
+            help=f"Paths ignored by default. "
+            f"A regular expression to exclude directories on file search.\n"
+            f"An empty value means no path is excluded. Default: {DEFAULT_EXCLUDES}",
+        )
+        optional.add_argument(
+            "--language",
+            "--lang",
+            action=ParseDelimitedArgAction,
+            default=self.language,
+            help="Parse Robot Framework files using additional languages.",
+        )
+        optional.add_argument("-h", "--help", action="help", help="Print this help message and exit.")
         optional.add_argument(
             "-v",
             "--version",
             action="version",
             version=__version__,
-            help=self.HELP_MSGS["help_version"],
+            help="Display Robocop version.",
+        )
+        optional.add_argument(
+            "-vv",
+            "--verbose",
+            action="store_true",
+            default=self.verbose,
+            help="Display extra information during execution.",
         )
-        optional.add_argument("-vv", "--verbose", action="store_true", help=self.HELP_MSGS["help_verbose"])
         optional.add_argument(
             "--directives",
             action="version",
-            version=self.HELP_MSGS["directives"],
+            version="1. Serve the public trust\n2. Protect the innocent\n3. Uphold the law\n4. [ACCESS DENIED]",
             help=argparse.SUPPRESS,
         )
 
         return parser
 
-    def parse_opts(self, args=None, from_cli=True):
-        args = self.preparse(args) if from_cli else None
-        if not args or args == ["--verbose"] or args == ["-vv"]:
-            loaded_args = self.load_default_config_file()
-            if loaded_args is None:
-                self.load_pyproject_file()
-            else:
-                # thanks for this we can have config file together with some cli options like --verbose
-                args = [*args, *loaded_args] if args is not None else loaded_args
-        if args:
-            args = self.parser.parse_args(args)
-            for key, value in dict(**vars(args)).items():
-                if key in self.__dict__:
-                    self.__dict__[key] = value
+    def parse(self):
+        if not self.from_cli:
+            self.load_default_config_file()
+            return
+        args = sys.argv[1:]
+        if not self.argument_file_in_cli(args):
+            self.load_default_config_file()
+        self.parse_args(args)
+
+    def argument_file_in_cli(self, args):
+        argument_options = {"-A", "--argumentfile"}
+        for arg in args:
+            if arg in argument_options:
+                return True
+        return False
+
+    def reload(self, rules):
         self.remove_severity()
         self.translate_patterns()
-        if self.verbose:
-            if self.config_from:
-                print(f"Loaded configuration from {self.config_from}")
-            else:
-                print("No config file found or configuration is empty. Using default configuration")
+        self.print_config_source()
+        self.validate_rule_names(rules)
 
-        return args
+    def print_config_source(self):
+        # We can only print after reading all configs, since self.verbose is unknown before we read it from config
+        if not self.verbose:
+            return
+        if self.config_from:
+            print(f"Loaded configuration from {self.config_from}")
+        else:
+            print("No config file found or configuration is empty. Using default configuration")
 
     def load_default_config_file(self):
-        robocop_path = self.find_file_in_project_root(".robocop")
-        if robocop_path.is_file():
-            return self.load_args_from_file(robocop_path)
-        return None
+        if not self.load_robocop_file():
+            self.load_pyproject_file()
 
-    def find_file_in_project_root(self, config_name):
-        root = self.root or Path.cwd()
-        for parent in (root, *root.parents):
-            if (parent / ".git").exists() or (parent / config_name).is_file():
-                return parent / config_name
-        return parent / config_name
+    def load_robocop_file(self):
+        """Returns True if .robocop exists"""
+        robocop_path = find_file_in_project_root(".robocop", self.root)
+        if not robocop_path.is_file():
+            return False
+        argument_files_parser = ArgumentFileParser()
+        args = argument_files_parser.load_argument_file(robocop_path, robocop_path.parent)
+        self.config_from = argument_files_parser.config_from
+        self.parse_args(args)
+        return True
 
     def load_pyproject_file(self):
-        pyproject_path = self.find_file_in_project_root("pyproject.toml")
+        pyproject_path = find_file_in_project_root("pyproject.toml", self.root)
         if not pyproject_path.is_file():
             return
+        config_dir = pyproject_path.parent
         try:
-            config = toml.load(str(pyproject_path))
-        except toml.TomlDecodeError as err:
+            with Path(pyproject_path).open("rb") as fp:
+                config = tomli.load(fp)
+        except tomli.TOMLDecodeError as err:
             raise InvalidArgumentError(f"Failed to decode {str(pyproject_path)}: {err}") from None
         config = config.get("tool", {}).get("robocop", {})
-        if self.parse_toml_to_config(config):
+        if self.parse_toml_to_config(config, config_dir):
             self.config_from = pyproject_path
 
+    def parse_args_to_config(self, args):
+        parser = self._create_parser()
+        args = parser.parse_args(args)
+        for key, value in dict(**vars(args)).items():
+            if key in self.__dict__:
+                self.__dict__[key] = value
+
+    def parse_args(self, args):
+        argument_files_parser = ArgumentFileParser()
+        args = argument_files_parser.expand_argument_files(args)
+        if argument_files_parser.config_from:
+            self.config_from = argument_files_parser.config_from
+        self.parse_args_to_config(args)
+
     @staticmethod
-    def replace_in_set(container, old_key, new_key):
+    def replace_in_set(container: Set, old_key: str, new_key: str):
         if old_key not in container:
             return
         container.remove(old_key)
@@ -404,10 +490,9 @@ class Config:
     def validate_rule_names(self, rules):
         # add rule name in form of old_name: new_name
         deprecated = {
-            "missing-whitespace-after-setting": "not-enough-whitespace-after-setting",
-            "variable-should-left-aligned": "variable-should-be-left-aligned",
-            "0304": "0406",
-            "invalid-char-in-name": "not-allowed-char-in-name",
+            "uneven-indent": "bad-indent",
+            "could-be-forced-tags": "could-be-test-tags",
+            "tag-already-set-in-force-tags": "tag-already-set-in-test-tags",
         }
         for rule in chain(self.include, self.exclude):
             if rule in deprecated:  # update warning description to specific case
@@ -415,13 +500,13 @@ class Config:
                     f"### DEPRECATION WARNING ###\nThe name (or ID) of the rule '{rule}' is "
                     f"renamed to '{deprecated[rule]}'. "
                     f"Update your configuration if you're using old name. "
-                    f"This information will disappear in the next version (1.12.0)\n\n"
+                    f"This information will disappear in the next version.\n\n"
                 )
                 self.replace_in_set(self.include, rule, deprecated[rule])
                 self.replace_in_set(self.exclude, rule, deprecated[rule])
             elif rule not in rules:
                 similar = RecommendationFinder().find_similar(rule, rules)
-                raise ConfigGeneralError(f"Provided rule '{rule}' does not exist.{similar}")
+                raise ConfigGeneralError(f"Provided rule '{rule}' does not exist. {similar}")
 
     def is_rule_enabled(self, rule):
         if self.is_rule_disabled(rule):
@@ -436,6 +521,8 @@ class Config:
         return True
 
     def is_rule_disabled(self, rule):
+        if not rule.enabled_in_version:
+            return True
         if rule.severity < self.threshold:
             return True
         if rule.rule_id in self.exclude or rule.name in self.exclude:
@@ -449,32 +536,45 @@ class Config:
         for pattern in self.ignore:
             if path.match(pattern):
                 return True
+        if self.ignore_default:
+            match = self.ignore_default.search(str(path))
+            return bool(match and match.group(0))
         return False
 
     @staticmethod
-    def replace_severity_values(message):
-        sev = "".join(c.value for c in RuleSeverity)
-        if re.match(f"[{sev}][0-9]{{4,}}", message):
+    def replace_severity_values(rule_name: str):
+        sev = "".join(sev.value for sev in RuleSeverity)
+        if re.match(f"[{sev}][0-9]{{4,}}", rule_name):
             for char in sev:
-                message = message.replace(char, "")
-        return message
+                rule_name = rule_name.replace(char, "")
+        return rule_name
 
-    def parse_toml_to_config(self, toml_data):
+    def parse_toml_to_config(self, toml_data: Dict, config_dir: Path):
         if not toml_data:
             return False
-        assign_type = {"paths", "format", "configure"}
-        set_type = {"include", "exclude", "reports", "ignore", "ext_rules"}
+        resolve_relative = {"paths", "ext_rules", "output"}
+        assign_type = {"paths", "format"}
+        set_type = {"include", "exclude", "ignore", "ext_rules"}
+        append_type = {"configure", "reports", "language"}
         toml_data = {key.replace("-", "_"): value for key, value in toml_data.items()}
         for key, value in toml_data.items():
+            if key in resolve_relative:
+                if isinstance(value, list):
+                    for index, val in enumerate(value):
+                        value[index] = resolve_relative_path(val, config_dir, ensure_exists=key == "ext_rules")
+                else:
+                    value = resolve_relative_path(value, config_dir, ensure_exists=key == "ext_rules")
             if key in assign_type:
                 self.__dict__[key] = value
             elif key in set_type:
                 self.__dict__[key].update(set(value))
+            elif key in append_type:
+                self.__dict__[key] += value
             elif key == "filetypes":
                 for filetype in toml_data["filetypes"]:
                     self.filetypes.add(filetype if filetype.startswith(".") else "." + filetype)
             elif key == "threshold":
-                self.threshold = find_severity_value(value)
+                self.threshold = RuleSeverity(value)
             elif key == "output":
                 self.output = open(value, "w")
             elif key == "no_recursive":
