@@ -1,27 +1,20 @@
 """
 Main class of Robocop module. Gathers files to be scanned, checkers, parses CLI arguments and scans files.
 """
-import inspect
-import sys
 import os
-from pathlib import Path
+import sys
 from collections import Counter
 
 from robot.api import get_resource_model
 from robot.errors import DataError
 
 import robocop.exceptions
-from robocop import checkers
-from robocop import reports
+from robocop import checkers, reports
 from robocop.config import Config
-from robocop.utils import (
-    DisablersFinder,
-    FileType,
-    FileTypeChecker,
-    issues_to_lsp_diagnostic,
-    RecommendationFinder,
-    is_suite_templated,
-)
+from robocop.files import get_files
+from robocop.rules import Message
+from robocop.utils import DisablersFinder, FileType, FileTypeChecker, RecommendationFinder, is_suite_templated
+from robocop.utils.file_types import check_model_type, get_resource_with_lang
 
 
 class Robocop:
@@ -46,18 +39,16 @@ class Robocop:
 
     """
 
-    def __init__(self, from_cli=False, config=None):
+    def __init__(self, from_cli: bool = False, config: Config = None):
         self.files = {}
         self.checkers = []
         self.rules = {}
         self.reports = {}
-        self.disabler = None
         self.root = os.getcwd()
         self.config = Config(from_cli=from_cli) if config is None else config
         self.from_cli = from_cli
-        self.config.parse_opts(from_cli=from_cli)
         if not from_cli:
-            self.config.reports.add("json_report")
+            self.config.reports.append("json_report")
         self.out = self.set_output()
 
     def set_output(self):
@@ -71,15 +62,15 @@ class Robocop:
     def reload_config(self):
         """Reload checkers and reports based on current config"""
         self.load_checkers()
-        self.config.validate_rule_names(self.rules)
-        self.list_checkers()
+        self.config.reload(self.rules)
         self.load_reports()
         self.configure_checkers_or_reports()
+        self.check_for_disabled_rules()
+        self.list_checkers()
 
     def run(self):
         """Entry point for running scans"""
         self.reload_config()
-
         self.recognize_file_types()
         self.run_checks()
         self.make_reports()
@@ -94,12 +85,11 @@ class Robocop:
         """
         Pre-parse files to recognize their types. If the filename is `__init__.*`, the type is `INIT`.
         Files with .resource extension are `RESOURCE` type.
-        If the file is imported somewhere then file type is `RESOURCE`. Otherwise file type is `GENERAL`.
+        If the file is imported somewhere then file type is `RESOURCE`. Otherwise, file type is `GENERAL`.
         These types are important since they are used to define parsing class for robot API.
         """
-        files = self.config.paths
         file_type_checker = FileTypeChecker(self.config.exec_dir)
-        for file in self.get_files(files, self.config.recursive):
+        for file in get_files(self.config):
             if "__init__" in file.name:
                 file_type = FileType.INIT
             elif file.suffix.lower() == ".resource":
@@ -108,8 +98,9 @@ class Robocop:
                 file_type = FileType.GENERAL
             file_type_checker.source = file
             try:
-                model = file_type.get_parser()(str(file))
-                file_type_checker.visit(model)
+                resource_parser = file_type.get_parser()
+                model = get_resource_with_lang(resource_parser, str(file), self.config.language)
+                check_model_type(file_type_checker, model)
                 self.files[file] = (file_type, model)
             except DataError:
                 print(f"Failed to decode {file}. Default supported encoding by Robot Framework is UTF-8. Skipping file")
@@ -118,7 +109,7 @@ class Robocop:
             if resource in self.files and self.files[resource][0].value != FileType.RESOURCE:
                 self.files[resource] = (
                     FileType.RESOURCE,
-                    get_resource_model(str(resource)),
+                    get_resource_with_lang(get_resource_model, str(resource), self.config.language),
                 )
 
     def run_checks(self):
@@ -127,7 +118,6 @@ class Robocop:
                 print(f"Scanning file: {file}")
             model = self.files[file][1]
             found_issues = self.run_check(model, str(file))
-            issues_to_lsp_diagnostic(found_issues)
             found_issues.sort()
             for issue in found_issues:
                 self.report(issue)
@@ -135,10 +125,10 @@ class Robocop:
             self.reports["file_stats"].files_count = len(self.files)
 
     def run_check(self, ast_model, filename, source=None):
-        found_issues = []
-        self.register_disablers(filename, source)
-        if self.disabler.file_disabled:
+        disablers = DisablersFinder(filename=filename, source=source)
+        if disablers.file_disabled:
             return []
+        found_issues = []
         templated = is_suite_templated(ast_model)
         for checker in self.checkers:
             if checker.disabled:
@@ -146,15 +136,11 @@ class Robocop:
             found_issues += [
                 issue
                 for issue in checker.scan_file(ast_model, filename, source, templated)
-                if not self.disabler.is_rule_disabled(issue)
+                if not disablers.is_rule_disabled(issue)
             ]
         return found_issues
 
-    def register_disablers(self, filename, source):
-        """Parse content of file to find any disabler statements like # robocop: disable=rulename"""
-        self.disabler = DisablersFinder(filename=filename, source=source)
-
-    def report(self, rule_msg):
+    def report(self, rule_msg: Message):
         for report in self.reports.values():
             report.add_message(rule_msg)
         try:
@@ -188,99 +174,70 @@ class Robocop:
         if self.config.list_configurables:
             print(
                 "All rules have configurable parameter 'severity'. Allowed values are:"
-                "\n    E / error\n    W / warning\n    I / info"
+                "\n    E / error\n    W / warning\n    I / info\n"
             )
         pattern = self.config.list if self.config.list else self.config.list_configurables
-        rule_by_id = [
-            (msg.rule_id, msg, checker)
-            for checker in self.checkers
-            for msg in checker.rules_map.values()
-            if msg.matches_pattern(pattern)
-        ]
-        rule_by_id = sorted(rule_by_id, key=lambda x: x[0])
+        if pattern in ("ENABLED", "DISABLED"):
+            rule_by_id = {
+                rule.rule_id: rule for rule in self.rules.values() if pattern.lower() in rule.get_enabled_status_desc()
+            }
+        else:
+            rule_by_id = {rule.rule_id: rule for rule in self.rules.values() if rule.matches_pattern(pattern)}
+        rule_by_id = sorted(rule_by_id.values(), key=lambda x: x.rule_id)
         severity_counter = Counter({"E": 0, "W": 0, "I": 0})
-        for _, rule_def, checker in rule_by_id:
+        for rule in rule_by_id:
             if self.config.list:
-                print(rule_def)
-                severity_counter[rule_def.severity.value] += 1
+                print(rule)
+                severity_counter[rule.severity.value] += 1
             else:
-                configurables = rule_def.available_configurables(include_severity=False, checker=checker)
-                if configurables:
-                    print(f"{rule_def}\n" f"    {configurables}")
-                    severity_counter[rule_def.severity.value] += 1
+                _, params = rule.available_configurables(include_severity=False)
+                if params:
+                    print(f"{rule}\n" f"    {params}")
+                    severity_counter[rule.severity.value] += 1
+        configurable_rules_sum = sum(severity_counter.values())
+        plural = "" if configurable_rules_sum == 1 else "s"
         print(
-            f"\nAltogether {sum(severity_counter.values())} rule(s) with following severity:\n"
-            f"    {severity_counter['E']} error rule(s),\n"
-            f"    {severity_counter['W']} warning rule(s),\n"
-            f"    {severity_counter['I']} info rule(s)."
+            f"\nAltogether {configurable_rules_sum} rule{plural} with following severity:\n"
+            f"    {severity_counter['E']} error rule{'' if severity_counter['E'] == 1 else 's'},\n"
+            f"    {severity_counter['W']} warning rule{'' if severity_counter['W'] == 1 else 's'},\n"
+            f"    {severity_counter['I']} info rule{'' if severity_counter['I'] == 1 else 's'}.\n"
         )
+        print("Visit https://robocop.readthedocs.io/en/stable/rules.html page for detailed documentation.")
         sys.exit()
 
     def load_reports(self):
-        self.reports = {}
-        classes = inspect.getmembers(reports, inspect.isclass)
-        available_reports = "Available reports:\n"
-        for report_class in classes:
-            if not issubclass(report_class[1], reports.Report):
-                continue
-            report = report_class[1]()
-            if not hasattr(report, "name"):
-                continue
-            if "all" in self.config.reports or report.name in self.config.reports:
-                self.reports[report.name] = report
-            available_reports += f"{report.name:20} - {report.description}\n"
+        self.reports = reports.get_reports(self.config.reports)
         if self.config.list_reports:
-            available_reports += "all" + " " * 18 + "- Turns on all available reports"
+            available_reports = reports.list_reports(self.reports)
             print(available_reports)
             sys.exit()
 
     def register_checker(self, checker):
-        if not self.any_rule_enabled(checker):
-            checker.disabled = True
-        for rule_name, rule in checker.rules_map.items():
-            if rule_name in self.rules:
-                (_, checker_prev) = self.rules[rule_name]
-                raise robocop.exceptions.DuplicatedRuleError("name", rule_name, checker, checker_prev)
-            if rule.rule_id in self.rules:
-                (_, checker_prev) = self.rules[rule.rule_id]
-                raise robocop.exceptions.DuplicatedRuleError("id", rule.rule_id, checker, checker_prev)
-            self.rules[rule_name] = (rule, checker)
-            self.rules[rule.rule_id] = (rule, checker)
+        for rule_name, rule in checker.rules.items():
+            self.rules[rule_name] = rule
+            self.rules[rule.rule_id] = rule
         self.checkers.append(checker)
 
+    def check_for_disabled_rules(self):
+        """Check checker configuration to disable rules."""
+        for checker in self.checkers:
+            if not self.any_rule_enabled(checker):
+                checker.disabled = True
+
     def make_reports(self):
         for report in self.reports.values():
-            output = report.get_report()
+            if report.name == "sarif":
+                output = report.get_report(self.config, self.rules)
+            else:
+                output = report.get_report()
             if output is not None:
                 self.write_line(output)
 
-    def get_files(self, files_or_dirs, recursive):
-        for file in files_or_dirs:
-            yield from self.get_absolute_path(Path(file), recursive)
-
-    def get_absolute_path(self, path, recursive):
-        if not path.exists():
-            raise robocop.exceptions.FileError(path)
-        if self.config.is_path_ignored(path):
-            return
-        if path.is_file():
-            if self.should_parse(path):
-                yield path.absolute()
-        elif path.is_dir():
-            for file in path.iterdir():
-                if file.is_dir() and not recursive:
-                    continue
-                yield from self.get_absolute_path(file, recursive)
-
-    def should_parse(self, file):
-        """Check if file extension is in list of supported file types (can be configured from cli)"""
-        return file.suffix and file.suffix.lower() in self.config.filetypes
-
-    def any_rule_enabled(self, checker):
-        for name, rule in checker.rules_map.items():
+    def any_rule_enabled(self, checker) -> bool:
+        for name, rule in checker.rules.items():
             rule.enabled = self.config.is_rule_enabled(rule)
-            checker.rules_map[name] = rule
-        return any(msg.enabled for msg in checker.rules_map.values())
+            checker.rules[name] = rule
+        return any(msg.enabled for msg in checker.rules.values())
 
     def configure_checkers_or_reports(self):
         for config in self.config.configure:
@@ -290,28 +247,30 @@ class Robocop:
                 )
             rule_or_report, param, value = config.split(":", maxsplit=2)
             if rule_or_report in self.rules:
-                msg, checker = self.rules[rule_or_report]
-                if param == "severity":
-                    msg.change_severity(value)
-                else:
-                    configurable = msg.get_configurable(param)
-                    if configurable is None:
-                        available_conf = msg.available_configurables(checker=checker)
-                        raise robocop.exceptions.ConfigGeneralError(
-                            f"Provided param '{param}' for rule '{rule_or_report}' does not exist. "
-                            f"Available configurable(s) for this rule:\n"
-                            f"    {available_conf}"
-                        )
-                    checker.configure(configurable[1], configurable[2](value))
+                rule = self.rules[rule_or_report]
+                rule.configure(param, value)
             elif rule_or_report in self.reports:
                 self.reports[rule_or_report].configure(param, value)
             else:
                 similar = RecommendationFinder().find_similar(rule_or_report, self.rules)
                 raise robocop.exceptions.ConfigGeneralError(
-                    f"Provided rule or report '{rule_or_report}' does not exist.{similar}"
+                    f"Provided rule or report '{rule_or_report}' does not exist. {similar}"
                 )
 
 
 def run_robocop():
-    linter = Robocop(from_cli=True)
-    linter.run()
+    try:
+        linter = Robocop(from_cli=True)
+        linter.run()
+    except robocop.exceptions.RobotFrameworkParsingError:
+        raise
+    except robocop.exceptions.RobocopFatalError as err:
+        print(f"Error: {err}")
+        sys.exit(1)
+    except Exception as err:
+        message = (
+            "\nFatal exception occurred. You can create an issue at "
+            "https://github.com/MarketSquare/robotframework-robocop/issues/new/choose . Thanks!"
+        )
+        err.args = (err.args[0] + message,) + err.args[1:]
+        raise err
